/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id:
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.binding.ftp;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.petals.component.framework.util.Extensions;



/**
 * FTPProperties.java.
 *
 * @author eBM WebSourcing
 */
public class FTPSUProperties {

    /**
     * the number of properties.
     */
    public static final int NUMBER_PROPERTIES = 4;

    /**
     * the FTP server property.
     */
    public static final String FTP_SERVER = "ftp.server";

    /**
     * the FTP port property.
     */
    public static final String FTP_PORT = "ftp.port";

    /**
     * the FTP login property.
     */
    public static final String FTP_LOGIN = "ftp.login";

    /**
     * the FTP password property.
     */
    public static final String FTP_PASSWORD = "ftp.password";

    /**
     * the FTP folder.
     */
    public static final String FTP_FOLDER = "ftp.folder";

    /**
     * the FTP file name
     */
    public static final String FTP_FILENAME = "ftp.file-name";

    /**
     * the FTP operation
     */
    public static final String FTP_OPERATION = "ftp.operation";

    /**
     * the default FTP port.
     */
    public static final Integer DEFAULT_FTP_PORT = 21;

    /**
     * the default FTP login.
     */
    public static final String DEFAULT_FTP_LOGIN = "anonymous";

    /**
     * the default FTP password.
     */
    public static final String DEFAULT_FTP_PASSWORD = "";



    /**
     * the FTP server.
     */
    private String server;

    /**
     * the FTP port.
     */
    private int port;

    /**
     * the FTP login.
     */
    private String login;

    /**
     * the FTP password.
     */
    private String password;
    /**
     * the FTP operation
     */
    private String operation;


    /**
     * Creates a new instance of {@link FTPSUProperties}.
     *
     * @param extensions
     *            extensiosn contains inside the SU JBI descriptor
     * @throws FTPBCException
     *             impossible to get the SU parameters.
     */
    public FTPSUProperties(final Extensions extensions) throws Exception {
        this.server = extensions.getPetalsExtensions().getProperty(FTPSUProperties.FTP_SERVER);

        if (this.server == null) {
            throw new Exception("Error in SU configuration: "
                    + "the FTP server name is unknown");
        }

        String portS = extensions.getPetalsExtensions().getProperty(FTPSUProperties.FTP_PORT, FTPSUProperties.DEFAULT_FTP_PORT.toString());
        this.port = Integer.parseInt(portS);
        this.login = extensions.getPetalsExtensions().getProperty(FTPSUProperties.FTP_LOGIN, FTPSUProperties.DEFAULT_FTP_LOGIN);
        this.password = extensions.getPetalsExtensions().getProperty(FTPSUProperties.FTP_PASSWORD, FTPSUProperties.DEFAULT_FTP_PASSWORD);
    }

    /**
     * Get the FTP server.
     *
     * @return the FTP server
     */
    public String getFTPServer() {
        return this.server;
    }

    /**
     * Get the FTP port.
     *
     * @return the FTP port
     */
    public int getFTPPort() {
        return this.port;
    }

    /**
     * Get the FTP login.
     *
     * @return the FTP login
     */
    public String getFTPLogin() {
        return this.login;
    }

    /**
     * Get the FTP password.
     *
     * @return the FTP password
     */
    public String getFTPPassword() {
        return this.password;
    }

    /**
     * Get the FTP operation
     *
     * @return
     */
    public static String getFTP_OPERATION() {
		return FTP_OPERATION;
	}

    /**
     * Get the default su properties.
     *
     * @return all the properties
     */
    protected static Map<String, String> getDefaultProperties() {
        Map<String, String> result = new HashMap<String, String>(
                FTPSUProperties.NUMBER_PROPERTIES);
        result.put(FTPSUProperties.FTP_SERVER, null);
        result.put(FTPSUProperties.FTP_PORT, Integer
                .toString(FTPSUProperties.DEFAULT_FTP_PORT));
        result
                .put(FTPSUProperties.FTP_LOGIN,
                        FTPSUProperties.DEFAULT_FTP_LOGIN);
        result.put(FTPSUProperties.FTP_PASSWORD,
                FTPSUProperties.DEFAULT_FTP_PASSWORD);
        return result;
    }

}
